@@ -308,7 +308,7 @@ gdm_server_stop (GdmDisplay *disp)
 		    if (disp->servpid > 1 &&
 			kill (disp->servpid, SIGTERM) == 0) {
 			    waiting_for_server = TRUE;
-			    ve_waitpid_no_signal (disp->servpid, 0, 0);
+			    ve_waitpid_no_signal (disp->servpid, NULL, 0);
 			    waiting_for_server = FALSE;
 		    }
 	    }
@@ -1364,7 +1364,6 @@ gdm_server_alloc (gint id, const gchar *command)
     d->last_loop_start_time = 0;
     d->last_start_time = 0;
     d->retry_count = 0;
-    d->disabled = FALSE;
     d->sleep_before_run = 0;
     d->login = NULL;
 
